Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrUnsupportedBinary = errors.New("unsupported binary format") ErrSectionNotFound = errors.New("section not found") )
Functions ¶
func ExtractSectionFromBinary ¶
ExtractSectionFromBinary reads a named section from an executable image.
func FindSection ¶
FindSection reads section data from the currently running executable.
func InjectBinary ¶
InjectBinary injects named data in native structures for ELF/PE/Mach-O.
Types ¶
type Format ¶
type Format string
Format is a supported executable container format.
func DetectFormat ¶
DetectFormat identifies executable file format by magic bytes.
type InjectOptions ¶
type InjectOptions struct {
// ResignMachO requests ad-hoc re-signing for Mach-O outputs (macOS only).
ResignMachO bool
}
InjectOptions controls injection behavior.
func DefaultInjectOptions ¶
func DefaultInjectOptions() InjectOptions
DefaultInjectOptions returns recommended defaults for current host OS.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.